@@ -1114,15 +1114,18 @@ class NumerousAdminClient(NumerousClient):
 
     def update_job_by_backend(self, project, scenario, job, exe, message, status, log=None, complete=False):
         self._base_client.SetScenarioProgress(spm_pb2.ScenarioProgress(
-            project=project, scenario=scenario, spm_job_id=job,
+            project=project, scenario=scenario, job_id=job,
             message=message, status=status, progress=0
         ))
 
         if log is not None:
-            self._base_client.PushScenarioLogEntry(spm_pb2.ScenarioLogEntry(
-                project=project, scenario=scenario, spm_job_id=job, initialize=False, message=log
+            self._base_client.PushExecutionLogEntries(spm_pb2.LogEntries(
+                scenario=self._scenario,
+                execution_id=self._execution_id, log_entries=[log],
+                timestamps=[datetime.utcnow().timestamp()]
             ))
 
+
         if complete:
             self._base_client.CompleteExecutionIgnoreInstance(
                 spm_pb2.ExecutionMessage(project_id=project, scenario_id=scenario, job_id=job,
